==> percona-xtradb-cluster_8.0.34-26.orig.tar.gz: Percona-XtraDB-Cluster-8.0.34-26/percona-xtradb-cluster-galera/galera/src/CMakeFiles/galera_smm.dir/DependInfo.cmake <==
# The set of languages for which implicit dependencies are needed:
set(CMAKE_DEPENDS_LANGUAGES
  "CXX"
  )
# The set of files for implicit dependencies of each language:
set(CMAKE_DEPENDS_CHECK_CXX
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galera/src/wsrep_provider.cpp" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galera/src/CMakeFiles/galera_smm.dir/wsrep_provider.cpp.o"
  )
set(CMAKE_CXX_COMPILER_ID "GNU")

# Preprocessor definitions for this target.
set(CMAKE_TARGET_DEFINITIONS_CXX
  "BOOST_DATE_TIME_POSIX_TIME_STD_CONFIG=1"
  "BOOST_NO_CXX98_FUNCTION_BASE"
  "GALERA_HAVE_SSL"
  "GALERA_MULTIMASTER"
  "GALERA_REV=\"841837f\""
  "GALERA_VER=\"4.16\""
  "HAVE_ASIO_HPP"
  "HAVE_BOOST_SHARED_PTR_HPP"
  "HAVE_BYTESWAP_H"
  "HAVE_COMMON_H"
  "HAVE_CONFIG_H"
  "HAVE_ENDIAN_H"
  "HAVE_PSI_INTERFACE=1"
  "HAVE_STD_ARRAY"
  "HAVE_STD_UNORDERED_MAP"
  "LZ4_DISABLE_DEPRECATE_WARNINGS"
  "NDEBUG"
  "OPENSSL_HAS_SET_ECDH_AUTO"
  "PXC"
  "WSREP_PS_VAR_VALUE_BUFF_SIZE=4096"
  "_FILE_OFFSET_BITS=64"
  "_GNU_SOURCE"
  "_USE_MATH_DEFINES"
  "__STDC_FORMAT_MACROS"
  "__STDC_LIMIT_MACROS"
  "galera_smm_EXPORTS"
  )

# The include file search paths:
set(CMAKE_CXX_TARGET_INCLUDE_PATH
  "wsrep-lib/include"
  "wsrep-lib/wsrep-API/v26"
  "."
  "include"
  "percona-xtradb-cluster-galera"
  "percona-xtradb-cluster-galera/common"
  "percona-xtradb-cluster-galera/galera/src"
  "percona-xtradb-cluster-galera/galerautils/src"
  "percona-xtradb-cluster-galera/gcache/src"
  "percona-xtradb-cluster-galera/gcomm/src"
  "percona-xtradb-cluster-galera/gcs/src"
  "percona-xtradb-cluster-galera/wsrep/src"
  "extra/protobuf/protobuf-3.19.4/src"
  "percona-xtradb-cluster-galera/asio"
  )

# Targets to which this target links.
set(CMAKE_TARGET_LINKED_INFO_FILES
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galera/src/CMakeFiles/galera.dir/DependInfo.cmake"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/gcs/src/CMakeFiles/gcs.dir/DependInfo.cmake"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/gcomm/src/CMakeFiles/gcomm.dir/DependInfo.cmake"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/gcache/src/CMakeFiles/gcache.dir/DependInfo.cmake"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/src/CMakeFiles/galerautilsxx.dir/DependInfo.cmake"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/src/CMakeFiles/galerautils.dir/DependInfo.cmake"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/src/CMakeFiles/galerautils_hw_crc32c.dir/DependInfo.cmake"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/src/CMakeFiles/galerautils_log.dir/DependInfo.cmake"
  )

# Fortran module output directory.
set(CMAKE_Fortran_TARGET_MODULE_DIR "")

==> percona-xtradb-cluster_8.0.39-30.orig.tar.gz: Percona-XtraDB-Cluster-8.0.39-30/percona-xtradb-cluster-galera/galera/src/CMakeFiles/galera_smm.dir/DependInfo.cmake <==
# The set of languages for which implicit dependencies are needed:
set(CMAKE_DEPENDS_LANGUAGES
  "CXX"
  )
# The set of files for implicit dependencies of each language:
set(CMAKE_DEPENDS_CHECK_CXX
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galera/src/wsrep_provider.cpp" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galera/src/CMakeFiles/galera_smm.dir/wsrep_provider.cpp.o"
  )
set(CMAKE_CXX_COMPILER_ID "GNU")

# Preprocessor definitions for this target.
set(CMAKE_TARGET_DEFINITIONS_CXX
  "BOOST_BIND_GLOBAL_PLACEHOLDERS=1"
  "BOOST_DATE_TIME_POSIX_TIME_STD_CONFIG=1"
  "BOOST_NO_CXX98_FUNCTION_BASE"
  "GALERA_HAVE_SSL"
  "GALERA_MULTIMASTER"
  "GALERA_REV=\"4ddd3b0\""
  "GALERA_VER=\"4.20\""
  "HAVE_ASIO_HPP"
  "HAVE_BOOST_SHARED_PTR_HPP"
  "HAVE_BYTESWAP_H"
  "HAVE_COMMON_H"
  "HAVE_CONFIG_H"
  "HAVE_ENDIAN_H"
  "HAVE_PSI_INTERFACE=1"
  "HAVE_STD_ARRAY"
  "HAVE_STD_UNORDERED_MAP"
  "LZ4_DISABLE_DEPRECATE_WARNINGS"
  "NDEBUG"
  "OPENSSL_HAS_SET_ECDH_AUTO"
  "PXC"
  "WSREP_PS_VAR_VALUE_BUFF_SIZE=4096"
  "_FILE_OFFSET_BITS=64"
  "_GNU_SOURCE"
  "_USE_MATH_DEFINES"
  "_XOPEN_SOURCE=600"
  "__STDC_FORMAT_MACROS"
  "__STDC_LIMIT_MACROS"
  "galera_smm_EXPORTS"
  )

# The include file search paths:
set(CMAKE_CXX_TARGET_INCLUDE_PATH
  "wsrep-lib/include"
  "wsrep-lib/wsrep-API/v26"
  "."
  "include"
  "percona-xtradb-cluster-galera"
  "percona-xtradb-cluster-galera/common"
  "percona-xtradb-cluster-galera/galera/src"
  "percona-xtradb-cluster-galera/galerautils/src"
  "percona-xtradb-cluster-galera/gcache/src"
  "percona-xtradb-cluster-galera/gcomm/src"
  "percona-xtradb-cluster-galera/gcs/src"
  "percona-xtradb-cluster-galera/wsrep/src"
  "extra/protobuf/protobuf-24.4/src"
  "percona-xtradb-cluster-galera/asio"
  )

# Targets to which this target links.
set(CMAKE_TARGET_LINKED_INFO_FILES
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galera/src/CMakeFiles/galera.dir/DependInfo.cmake"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/gcs/src/CMakeFiles/gcs.dir/DependInfo.cmake"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/gcomm/src/CMakeFiles/gcomm.dir/DependInfo.cmake"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/gcache/src/CMakeFiles/gcache.dir/DependInfo.cmake"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/src/CMakeFiles/galerautilsxx.dir/DependInfo.cmake"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/src/CMakeFiles/galerautils.dir/DependInfo.cmake"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/src/CMakeFiles/galerautils_hw_crc32c.dir/DependInfo.cmake"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/src/CMakeFiles/galerautils_log.dir/DependInfo.cmake"
  )

# Fortran module output directory.
set(CMAKE_Fortran_TARGET_MODULE_DIR "")
